@@ -56,4 +56,4 @@ class EquidistantNoLeft(CollBase):
         b = self.tright
         nodes = np.linspace(a, b, M + 1)
         nodes = nodes[1:]
-        return nodes
+        return nodes.squeeze()
