@@ -35,12 +35,12 @@ class controller_nonMPI(controller):
 
         # try to initialize via dill.copy (much faster for many time-steps)
         try:
-            for p in range(num_procs - 1):
+            for _ in range(num_procs - 1):
                 self.MS.append(dill.copy(self.MS[0]))
         # if this fails (e.g. due to un-picklable data in the steps), initialize seperately
         except dill.PicklingError and TypeError:
             self.logger.warning('Need to initialize steps separately due to pickling error')
-            for p in range(num_procs - 1):
+            for _ in range(num_procs - 1):
                 self.MS.append(stepclass.step(description))
 
         if self.params.dump_setup:
@@ -132,7 +132,7 @@ class controller_nonMPI(controller):
         self.hooks.reset_stats()
 
         # initial ordering of the steps: 0,1,...,Np-1
-        slots = [p for p in range(num_procs)]
+        slots = list(range(num_procs))
 
         # initialize time variables of each step
         time = [t0 + sum(self.MS[j].dt for j in range(p)) for p in slots]
@@ -548,7 +548,7 @@ class controller_nonMPI(controller):
 
                 # sweep on middle levels (not on finest, not on coarsest, though)
 
-                for k in range(self.nsweeps[l]):
+                for _ in range(self.nsweeps[l]):
 
                     for S in local_MS_running:
 
@@ -675,7 +675,7 @@ class controller_nonMPI(controller):
             raise ControllerError('Unknown stage, got %s' % local_MS_running[0].status.stage)  # TODO
 
         # if all stages are the same (or DONE), continue, otherwise abort
-        stages = [S.status.stage for S in local_MS_active if S.status.stage is not 'DONE']
+        stages = [S.status.stage for S in local_MS_active if S.status.stage != 'DONE']
         if stages[1:] == stages[:-1]:
             stage = stages[0]
         else:
@@ -683,7 +683,7 @@ class controller_nonMPI(controller):
 
         self.logger.debug(stage)
 
-        MS_running = [S for S in local_MS_active if S.status.stage is not 'DONE']
+        MS_running = [S for S in local_MS_active if S.status.stage != 'DONE']
 
         switcher = {
             'SPREAD': spread,
