@@ -54,7 +54,8 @@ class allencahn_temp_imex(ptype):
         # creating FFT structure
         ndim = len(problem_params['nvars'])
         axes = tuple(range(ndim))
-        self.fft = PFFT(problem_params['comm'], list(problem_params['nvars']), axes=axes, dtype=np.float, collapse=True)
+        self.fft = PFFT(problem_params['comm'], list(problem_params['nvars']), axes=axes, dtype=np.float64,
+                        collapse=True)
 
         # get test data to figure out type and dimensions
         tmp_u = newDistArray(self.fft, problem_params['spectral'])
@@ -122,7 +123,7 @@ class allencahn_temp_imex(ptype):
                 f.expl[..., 0] = self.fft.forward(tmpf)
 
             f.impl[..., 1] = -self.params.D * self.K2 * u[..., 1]
-            f.expl[..., 1] = -f.impl[..., 0] - f.expl[..., 0]
+            f.expl[..., 1] = f.impl[..., 0] + f.expl[..., 0]
 
         else:
 
@@ -138,7 +139,7 @@ class allencahn_temp_imex(ptype):
             u_hat = self.fft.forward(u[..., 1])
             lap_u_hat = -self.params.D * self.K2 * u_hat
             f.impl[..., 1] = self.fft.backward(lap_u_hat, f.impl[..., 1])
-            f.expl[..., 1] = -f.impl[..., 0] - f.expl[..., 0]
+            f.expl[..., 1] = f.impl[..., 0] + f.expl[..., 0]
 
         return f
 
@@ -225,10 +226,10 @@ class allencahn_temp_imex(ptype):
         def sine():
             tmp_me = newDistArray(self.fft, self.params.spectral)
             if self.params.spectral:
-                tmp = np.sin(2 * np.pi * self.X[0]) * np.sin(2 * np.pi * self.X[1])
+                tmp = 0.5 * (2.0 + 0.0 * np.sin(2 * np.pi * self.X[0]) * np.sin(2 * np.pi * self.X[1]))
                 tmp_me[:] = self.fft.forward(tmp)
             else:
-                tmp_me[:] = np.sin(2 * np.pi * self.X[0]) * np.sin(2 * np.pi * self.X[1])
+                tmp_me[:] = 0.5 * (2.0 + 0.0 * np.sin(2 * np.pi * self.X[0]) * np.sin(2 * np.pi * self.X[1]))
             return tmp_me
 
         assert t == 0, 'ERROR: u_exact only valid for t=0'
