@@ -169,8 +169,8 @@ def main(nprocs_space=None, cwd='.'):
         print(f'Error: {errors[-1]:6.4e}')
         print(f'Order of accuracy: {orders[-1]:4.2f}\n')
 
-    assert errors[2 + 1] < 1.4E-09, f'Errors are too high, got {errors[2 + 1]}'
-    assert np.isclose(orders[3], 5, rtol=2E-02), f'Order of accuracy is not within tolerance, got {orders[3]}'
+    assert errors[2 + 1] < 8E-10, f'Errors are too high, got {errors[2 + 1]}'
+    assert np.isclose(orders[3], 5.3, rtol=2E-02), f'Order of accuracy is not within tolerance, got {orders[3]}'
 
     print()
 
@@ -183,8 +183,8 @@ def main(nprocs_space=None, cwd='.'):
         print(f'Error: {errors[-1]:6.4e}')
         print(f'Order of accuracy: {orders[-1]:4.2f}\n')
 
-    assert errors[2 + 1] < 1.4E-09, f'Errors are too high, got {errors[2 + 1]}'
-    assert np.isclose(orders[1], 5, rtol=7E-02), f'Order of accuracy is not within tolerance, got {orders[1]}'
+    assert errors[2 + 1] < 8E-10, f'Errors are too high, got {errors[2 + 1]}'
+    assert np.isclose(orders[1], 4.6, rtol=7E-02), f'Order of accuracy is not within tolerance, got {orders[1]}'
 
 
 if __name__ == "__main__":
