@@ -196,7 +196,7 @@ def show_results(fname):
     plt_helper.savefig(fname)
 
     assert os.path.isfile(fname + '.pdf'), 'ERROR: plotting did not create PDF file'
-    assert os.path.isfile(fname + '.pgf'), 'ERROR: plotting did not create PGF file'
+    # assert os.path.isfile(fname + '.pgf'), 'ERROR: plotting did not create PGF file'
     assert os.path.isfile(fname + '.png'), 'ERROR: plotting did not create PNG file'
 
     return None
