@@ -122,7 +122,7 @@ def main(ft_strategies):
         for k, v in extract_stats.items():
             step = k.process
             iter = k.iter
-            if iter is not -1:
+            if iter != -1:
                 residual[iter - 1, step] = np.log10(v)
 
         # stats magic: get niter (probably redundant with maxiter)
