@@ -1,6 +1,9 @@
 import os
 import subprocess
+import pytest
 
+@pytest.mark.slow
+@pytest.mark.parallel
 def test_preconditioner_playground_MPI_5():
     # Set python path once
     my_env = os.environ.copy()
@@ -14,6 +17,8 @@ def test_preconditioner_playground_MPI_5():
                               (p.returncode, num_procs)
 
 
+@pytest.mark.slow
+@pytest.mark.parallel
 def test_preconditioner_playground_MPI_3():
     # Set python path once
     my_env = os.environ.copy()
